@@ -35,8 +35,9 @@ distribution in various parts of the CPAN ecosystem.
 
 =cut
 
-use 5.00503;
+use 5.006;
 use strict;
+use warnings;
 use Carp;
 use File::Spec        0.82 ();
 use File::Spec::Unix       ();
@@ -44,12 +45,9 @@ use File::Find::Rule  0.20 ();
 use Params::Util      0.38 ();
 use Parse::CPAN::Meta 1.38 ();
 
-use vars qw{$VERSION @ISA @EXPORT};
-BEGIN {
-	$VERSION = '1.13';
-	@ISA     = 'File::Find::Rule';
-	@EXPORT  = @File::Find::Rule::EXPORT;
-}
+our $VERSION = '1.14';
+use base 'File::Find::Rule';
+our @EXPORT  = @File::Find::Rule::EXPORT;
 
 use constant FFR => 'File::Find::Rule';
 
